@@ -1,7 +1,7 @@
 import json
 import pickle
 import time
-from threading import Thread, Event, Lock
+from threading import Thread, Event, RLock
 
 import numpy as np
 import zmq
@@ -36,7 +36,7 @@ class DeviceClient(Device):
     def __init__(self, host, port, device_id=None, config=None):
         self.subscription_thread = None
         Device.__init__(self, device_id, config)
-        self.client_comm_lock = Lock()
+        self.client_comm_lock = RLock()
         self.host = host
         self.port = port
         self.removing = False
@@ -490,9 +490,9 @@ class DeviceClient(Device):
         message = self.socket.recv_multipart()
         status, token, msg_type = message[:3]
         if msg_type == MSG_JSON:
-            return status, token.decode(), message[3].decode()
+            return status.decode(), token.decode(), message[3].decode()
         elif msg_type == MSG_FILE:
-            return status, token.decode(), message[3].decode()
+            return status.decode(), token.decode(), message[3].decode()
 
     def handle_configuration(self):
         start_at = time.time()
