@@ -34,6 +34,8 @@ class MacroWidget(QWidget, YamlSerializable):
     def _show_method_attribute_widget(self, attribute_title, attribute, row):
         if attribute is None:
             attribute = Attribute("")
+        if self.config.get(attribute_title, False) and self.config.get(attribute_title, None) is not None:
+            attribute[VALUE] = self.config[attribute_title]
         attribute_widget = AttributeDisplayWidget(attribute_title, attribute, config={"label_width": 110})
         self.layout().addWidget(attribute_widget.label_widget, row, 0)
         self.layout().addWidget(attribute_widget.input_widget, row, 1)
