@@ -3,7 +3,7 @@ import re
 import time
 from collections import OrderedDict
 from datetime import datetime
-from threading import Lock
+from threading import RLock
 
 import numpy as np
 import oyaml
@@ -30,7 +30,7 @@ class MacroServer(Device):
         self.uploaded_macros = OrderedDict()
         self.running_macros = OrderedDict()
         self.finished_macros = OrderedDict()
-        self.update_lock = Lock()
+        self.update_lock = RLock()
         super().__init__(device_id, config)
         self.connect()
 
