@@ -1,7 +1,7 @@
 import asyncore
 import logging
 from collections import OrderedDict
-from threading import Thread, Event, Lock
+from threading import Thread, Event, Lock, RLock
 from time import sleep
 
 import numpy
@@ -14,7 +14,6 @@ class PortReadLoop(PreciseCallbackTimer):
 
     def __init__(self, interval=5):
         self.interval = interval
-        self.lock = Lock()
         self.logger = logging.getLogger(u"Console.PortReadLoop")
         PreciseCallbackTimer.__init__(self, interval, self.handle_interval_timeout)
         self.map = []
@@ -25,28 +24,25 @@ class PortReadLoop(PreciseCallbackTimer):
         PreciseCallbackTimer.run(self)
 
     def add_device(self, device):
-        with self.lock:
-            if device not in self.map:
-                self.map.append(device)
-                return True
-            else:
-                return False
+        if device not in self.map.copy():
+            self.map.append(device)
+            return True
+        else:
+            return False
 
     def remove_device(self, device):
-        with self.lock:
-            if device in self.map:
-                self.map.remove(device)
-                return True
-            else:
-                return False
+        if device in self.map.copy():
+            self.map.remove(device)
+            return True
+        else:
+            return False
 
     def handle_interval_timeout(self):
-        with self.lock:
-            for device in self.map:
-                try:
-                    device.handle_read()
-                except IOError:
-                    device.handle_response_error(u"Port read error")
+        for device in self.map.copy():
+            try:
+                device.handle_read()
+            except IOError:
+                device.handle_response_error(u"Port read error")
 
     def stop(self):
         self.logger.info(u"Stopping port readout loop Thread")
@@ -58,7 +54,6 @@ class DeviceConnectionPoller(CallbackTimer):
     def __init__(self, interval=2000):
         self.connecting_devices = []
         self.connected_devices = []
-        self.lock = Lock()
         self.interval = interval
         self.logger = logging.getLogger(u"Console.DeviceConnectionPoller")
         PreciseCallbackTimer.__init__(self, self.interval, self.check_devices_connection_timeout, with_correction=False)
@@ -68,19 +63,17 @@ class DeviceConnectionPoller(CallbackTimer):
         CallbackTimer.run(self)
 
     def add_connecting_device(self, device):
-        with self.lock:
-            if device not in self.connecting_devices:
-                self.connecting_devices.append(device)
+        if device not in self.connecting_devices:
+            self.connecting_devices.append(device)
 
     def remove_connecting_device(self, device):
-        with self.lock:
-            try:
-                self.connecting_devices.remove(device)
-            except ValueError:
-                pass  # device was removed already
+        try:
+            self.connecting_devices.remove(device)
+        except ValueError:
+            pass  # device was removed already
 
     def check_devices_connection_timeout(self):
-        for device in self.connecting_devices[:]:
+        for device in self.connecting_devices.copy():
             if not device.connected and not device.connecting and device.allow_reconnect and (
                     device.response_error or device.connection_error):
                 device.reconnect()
@@ -93,7 +86,7 @@ class DeviceConnectionPoller(CallbackTimer):
                 self.connected_devices.append(device)
             else:
                 device.connecting_time += self.interval
-        for device in self.connected_devices:
+        for device in self.connected_devices.copy():
             if not device.is_alive():
                 self.connected_devices.remove(device)
                 if device.allow_reconnect and (device.response_error or device.connection_error):
@@ -110,8 +103,8 @@ class DevicePoller(PreciseCallbackTimer):
         self.interval = interval
         self.commands_buffer = {}
         self.poll_commands_buffer = {}
-        self.poll_lock = Lock()
-        self.command_lock = Lock()
+        self.poll_lock = RLock()
+        self.command_lock = RLock()
         self.logger = logging.getLogger(u"Console.DevicePoller")
         self.polling_schedule = OrderedDict()
         self.schedule = []
