@@ -1,4 +1,5 @@
 import sys
+from threading import Timer
 from time import perf_counter_ns
 
 from kamzik3.snippets.snippetsInterfaces import CallbackTimerInterface
@@ -33,3 +34,24 @@ else:
     # We can get up to 1us resolution.
     class PreciseCallbackTimer(CallbackTimer):
         pass
+
+
+class RecallableTimer:
+
+    def __init__(self, interval, f, *args, **kwargs):
+        self.interval = interval
+        self.f = f
+        self.args = args
+        self.kwargs = kwargs
+
+        self.timer = None
+
+    def callback(self):
+        self.f(*self.args, **self.kwargs)
+
+    def cancel(self):
+        self.timer.cancel()
+
+    def start(self):
+        self.timer = Timer(self.interval, self.callback)
+        self.timer.start()
